package com.muyu.customer.business.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.customer.business.domain.req.FenceQueryReq;
import com.muyu.customer.business.domain.req.FenceSaveReq;
import com.muyu.customer.business.domain.req.FenceEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 电子围栏对象 fence
 *
 * @author muyu
 * @date 2024-05-31
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("fence")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Fence", description = "电子围栏")
public class Fence extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** id */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "id", value = "id")
    private Long id;

    /** 电子围栏名称 */
    @Excel(name = "电子围栏名称")
    @ApiModelProperty(name = "电子围栏名称", value = "电子围栏名称")
    private String name;

    /** 围栏类型 */
    @Excel(name = "围栏类型")
    @ApiModelProperty(name = "围栏类型", value = "围栏类型")
    private String fenceType;

    /** 经纬度信息 */
    @Excel(name = "经纬度信息")
    @ApiModelProperty(name = "经纬度信息", value = "经纬度信息")
    private String longitudeAndLatitude;

    /**
    * 查询构造器
    */
    public static Fence queryBuild( FenceQueryReq fenceQueryReq){
        return Fence.builder()
                .name(fenceQueryReq.getName())
                .fenceType(fenceQueryReq.getFenceType())
                .longitudeAndLatitude(fenceQueryReq.getLongitudeAndLatitude())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Fence saveBuild(FenceSaveReq fenceSaveReq){
        return Fence.builder()
                .name(fenceSaveReq.getName())
                .fenceType(fenceSaveReq.getFenceType())
                .longitudeAndLatitude(fenceSaveReq.getLongitudeAndLatitude())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Fence editBuild(Long id, FenceEditReq fenceEditReq){
        return Fence.builder()
            .id(id)
                .name(fenceEditReq.getName())
                .fenceType(fenceEditReq.getFenceType())
                .longitudeAndLatitude(fenceEditReq.getLongitudeAndLatitude())
                .build();
    }

}
