package com.muyu.customer.business.domain;

import java.math.BigDecimal;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.security.utils.SecurityUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.customer.business.domain.req.VehicleQueryReq;
import com.muyu.customer.business.domain.req.VehicleSaveReq;
import com.muyu.customer.business.domain.req.VehicleEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 车辆录入对象 vehicle
 *
 * @author muyu
 * @date 2024-05-27
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("vehicle")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Vehicle", description = "车辆录入")
public class Vehicle extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 车辆id */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "车辆id", value = "车辆id")
    private Long id;

    /** 车辆vin */
    @Excel(name = "车辆vin")
    @ApiModelProperty(name = "车辆vin", value = "车辆vin")
    private String vin;

    /** 品牌 */
    @Excel(name = "品牌")
    @ApiModelProperty(name = "品牌", value = "品牌")
    private String brand;

    /** 型号 */
    @Excel(name = "型号")
    @ApiModelProperty(name = "型号", value = "型号")
    private String model;

    /** 生产日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "生产日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "生产日期", value = "生产日期")
    private Date productionDate;

    /** 车身类型 */
    @Excel(name = "车身类型")
    @ApiModelProperty(name = "车身类型", value = "车身类型")
    private String bodyType;

    /** 车身颜色 */
    @Excel(name = "车身颜色")
    @ApiModelProperty(name = "车身颜色", value = "车身颜色")
    private String color;

    /** 发动机排量 */
    @Excel(name = "发动机排量")
    @ApiModelProperty(name = "发动机排量", value = "发动机排量")
    private BigDecimal engineCapacity;

    /** 燃油类型 */
    @Excel(name = "燃油类型")
    @ApiModelProperty(name = "燃油类型", value = "燃油类型")
    private String fuelType;

    /** 变速器类型 */
    @Excel(name = "变速器类型")
    @ApiModelProperty(name = "变速器类型", value = "变速器类型")
    private String transmission;

    /** 驱动方式 */
    @Excel(name = "驱动方式")
    @ApiModelProperty(name = "驱动方式", value = "驱动方式")
    private String driveType;

    /** 行驶里程 */
    @Excel(name = "行驶里程")
    @ApiModelProperty(name = "行驶里程", value = "行驶里程")
    private BigDecimal mileage;

    /** 注册日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "注册日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "注册日期", value = "注册日期")
    private Date registrationDate;

    /** 车牌号码 */
    @Excel(name = "车牌号码")
    @ApiModelProperty(name = "车牌号码", value = "车牌号码")
    private String licenseNumber;

    /** 持有者 */
    @Excel(name = "持有者")
    @ApiModelProperty(name = "持有者", value = "持有者")
    private String holder;

    /** 车辆类型 */
    @Excel(name = "车辆类型")
    @ApiModelProperty(name = "车辆类型", value = "车辆类型")
    private String vehicleType;

    /**
    * 查询构造器
    */
    public static Vehicle queryBuild( VehicleQueryReq vehicleQueryReq){
        return Vehicle.builder()
                .vin(vehicleQueryReq.getVin())
                .brand(vehicleQueryReq.getBrand())
                .model(vehicleQueryReq.getModel())
                .productionDate(vehicleQueryReq.getProductionDate())
                .bodyType(vehicleQueryReq.getBodyType())
                .color(vehicleQueryReq.getColor())
                .engineCapacity(vehicleQueryReq.getEngineCapacity())
                .fuelType(vehicleQueryReq.getFuelType())
                .transmission(vehicleQueryReq.getTransmission())
                .driveType(vehicleQueryReq.getDriveType())
                .mileage(vehicleQueryReq.getMileage())
                .registrationDate(vehicleQueryReq.getRegistrationDate())
                .licenseNumber(vehicleQueryReq.getLicenseNumber())
                .holder(vehicleQueryReq.getHolder())
                .vehicleType(vehicleQueryReq.getVehicleType())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Vehicle saveBuild(VehicleSaveReq vehicleSaveReq){
        return Vehicle.builder()
                .vin(vehicleSaveReq.getVin())
                .brand(vehicleSaveReq.getBrand())
                .model(vehicleSaveReq.getModel())
                .productionDate(vehicleSaveReq.getProductionDate())
                .bodyType(vehicleSaveReq.getBodyType())
                .color(vehicleSaveReq.getColor())
                .engineCapacity(vehicleSaveReq.getEngineCapacity())
                .fuelType(vehicleSaveReq.getFuelType())
                .transmission(vehicleSaveReq.getTransmission())
                .driveType(vehicleSaveReq.getDriveType())
                .mileage(vehicleSaveReq.getMileage())
                .registrationDate(vehicleSaveReq.getRegistrationDate())
                .licenseNumber(vehicleSaveReq.getLicenseNumber())
                .holder(vehicleSaveReq.getHolder())
                .vehicleType(vehicleSaveReq.getVehicleType())
                .createTime(new Date())
                .createBy(SecurityUtils.getUsername())
                .remark(vehicleSaveReq.getRemark())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Vehicle editBuild(Long id, VehicleEditReq vehicleEditReq){
        return Vehicle.builder()
            .id(id)
                .vin(vehicleEditReq.getVin())
                .brand(vehicleEditReq.getBrand())
                .model(vehicleEditReq.getModel())
                .productionDate(vehicleEditReq.getProductionDate())
                .bodyType(vehicleEditReq.getBodyType())
                .color(vehicleEditReq.getColor())
                .engineCapacity(vehicleEditReq.getEngineCapacity())
                .fuelType(vehicleEditReq.getFuelType())
                .transmission(vehicleEditReq.getTransmission())
                .driveType(vehicleEditReq.getDriveType())
                .mileage(vehicleEditReq.getMileage())
                .registrationDate(vehicleEditReq.getRegistrationDate())
                .licenseNumber(vehicleEditReq.getLicenseNumber())
                .holder(vehicleEditReq.getHolder())
                .vehicleType(vehicleEditReq.getVehicleType())
                .updateTime(new Date())
                .updateBy(SecurityUtils.getUsername())
                .remark(vehicleEditReq.getRemark())
                .build();
    }

}
