package com.muyu.net.working.domain;

import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.net.working.domain.req.EnterpriseQueryReq;
import com.muyu.net.working.domain.req.EnterpriseSaveReq;
import com.muyu.net.working.domain.req.EnterpriseEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 企业信息对象 enterprise
 *
 * @author muyu
 * @date 2024-05-27
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("enterprise")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Enterprise", description = "企业信息")
public class Enterprise extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private String id;

    /** 企业名称 */
    @Excel(name = "企业名称")
    @ApiModelProperty(name = "企业名称", value = "企业名称")
    private String ebterpriseName;

    /** 法定代表人 */
    @Excel(name = "法定代表人")
    @ApiModelProperty(name = "法定代表人", value = "法定代表人")
    private String legalPerson;

    /** 经营执照凭证号码 */
    @Excel(name = "经营执照凭证号码")
    @ApiModelProperty(name = "经营执照凭证号码", value = "经营执照凭证号码")
    private String businessLincenseNumber;

    /** 企业成立时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "企业成立时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "企业成立时间", value = "企业成立时间")
    private Date estabinessDate;

    /** 经营范围 */
    @Excel(name = "经营范围")
    @ApiModelProperty(name = "经营范围", value = "经营范围")
    private String businessScope;

    /** 注册地址 */
    @Excel(name = "注册地址")
    @ApiModelProperty(name = "注册地址", value = "注册地址")
    private String address;

    /** 企业联系方式 */
    @Excel(name = "企业联系方式")
    @ApiModelProperty(name = "企业联系方式", value = "企业联系方式")
    private String contactPhone;

    /** 公司邮箱 */
    @Excel(name = "公司邮箱")
    @ApiModelProperty(name = "公司邮箱", value = "公司邮箱")
    private String email;

    /** 企业当前状态 */
    @Excel(name = "企业当前状态")
    @ApiModelProperty(name = "企业当前状态", value = "企业当前状态")
    private String status;

    /** 企业入驻平台时期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "企业入驻平台时期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "企业入驻平台时期", value = "企业入驻平台时期")
    private Date registrationDate;

    /** 企业认证id */
    @Excel(name = "企业认证id")
    @ApiModelProperty(name = "企业认证id", value = "企业认证id")
    private Long certificationId;

    /** 认证时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "认证时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "认证时间", value = "认证时间")
    private Date authenticationDate;

    /** 服务级别 */
    @Excel(name = "服务级别")
    @ApiModelProperty(name = "服务级别", value = "服务级别")
    private Long serviceLevel;

    /** 开通服务id */
    @Excel(name = "开通服务id")
    @ApiModelProperty(name = "开通服务id", value = "开通服务id")
    private Long openServerId;

    /** 增值服务id */
    @Excel(name = "增值服务id")
    @ApiModelProperty(name = "增值服务id", value = "增值服务id")
    private Long addServerId;

    /**
    * 查询构造器
    */
    public static Enterprise queryBuild( EnterpriseQueryReq enterpriseQueryReq){
        return Enterprise.builder()
                .ebterpriseName(enterpriseQueryReq.getEbterpriseName())
                .legalPerson(enterpriseQueryReq.getLegalPerson())
                .businessLincenseNumber(enterpriseQueryReq.getBusinessLincenseNumber())
                .estabinessDate(enterpriseQueryReq.getEstabinessDate())
                .businessScope(enterpriseQueryReq.getBusinessScope())
                .address(enterpriseQueryReq.getAddress())
                .contactPhone(enterpriseQueryReq.getContactPhone())
                .email(enterpriseQueryReq.getEmail())
                .status(enterpriseQueryReq.getStatus())
                .registrationDate(enterpriseQueryReq.getRegistrationDate())
                .certificationId(enterpriseQueryReq.getCertificationId())
                .authenticationDate(enterpriseQueryReq.getAuthenticationDate())
                .serviceLevel(enterpriseQueryReq.getServiceLevel())
                .openServerId(enterpriseQueryReq.getOpenServerId())
                .addServerId(enterpriseQueryReq.getAddServerId())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Enterprise saveBuild(EnterpriseSaveReq enterpriseSaveReq){
        return Enterprise.builder()
                .ebterpriseName(enterpriseSaveReq.getEbterpriseName())
                .legalPerson(enterpriseSaveReq.getLegalPerson())
                .businessLincenseNumber(enterpriseSaveReq.getBusinessLincenseNumber())
                .estabinessDate(enterpriseSaveReq.getEstabinessDate())
                .businessScope(enterpriseSaveReq.getBusinessScope())
                .address(enterpriseSaveReq.getAddress())
                .contactPhone(enterpriseSaveReq.getContactPhone())
                .email(enterpriseSaveReq.getEmail())
                .status(enterpriseSaveReq.getStatus())
                .registrationDate(enterpriseSaveReq.getRegistrationDate())
                .certificationId(enterpriseSaveReq.getCertificationId())
                .authenticationDate(enterpriseSaveReq.getAuthenticationDate())
                .serviceLevel(enterpriseSaveReq.getServiceLevel())
                .openServerId(enterpriseSaveReq.getOpenServerId())
                .addServerId(enterpriseSaveReq.getAddServerId())
                .createBy(enterpriseSaveReq.getCreateBy())
                .createTime(new Date())
                .remark(enterpriseSaveReq.getRemark())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Enterprise editBuild(String id, EnterpriseEditReq enterpriseEditReq){
        return Enterprise.builder()
            .id(id)
                .ebterpriseName(enterpriseEditReq.getEbterpriseName())
                .legalPerson(enterpriseEditReq.getLegalPerson())
                .businessLincenseNumber(enterpriseEditReq.getBusinessLincenseNumber())
                .estabinessDate(enterpriseEditReq.getEstabinessDate())
                .businessScope(enterpriseEditReq.getBusinessScope())
                .address(enterpriseEditReq.getAddress())
                .contactPhone(enterpriseEditReq.getContactPhone())
                .email(enterpriseEditReq.getEmail())
                .status(enterpriseEditReq.getStatus())
                .registrationDate(enterpriseEditReq.getRegistrationDate())
                .certificationId(enterpriseEditReq.getCertificationId())
                .authenticationDate(enterpriseEditReq.getAuthenticationDate())
                .serviceLevel(enterpriseEditReq.getServiceLevel())
                .openServerId(enterpriseEditReq.getOpenServerId())
                .addServerId(enterpriseEditReq.getAddServerId())
                .updateBy(enterpriseEditReq.getUpdateBy())
                .updateTime(new Date())
                .remark(enterpriseEditReq.getRemark())
                .build();
    }

}
